## usage: ret_set = expsmooth (data_set, k)
##
## Performs exponential smoothing on a data set,
## using a smoothing constant, k.
##
## Based on: Devore, J. _Probability and Statistics for Engineering 
##               and the Sciences. Duxbury, 1999. 50.
##
## Author: Kevin Straight stra9456@uidaho.edu

function ret_set=expsmooth (data_set, k)

     if( (nargin < 2) || (k < 0) || (k > 1) )
       usage ("ret_set = expsmooth (data_set, k)");
     endif

     if(rows(data_set) < columns (data_set))
       data_set = rot90(data_set);
     endif
   
     ret_set = zeros(rows(data_set), 1);

     ret_set(1) = data_set(1);

     for i=2:rows(data_set)
       ret_set(i) = k*data_set(i) + (1 - k)*ret_set(i-1);
     endfor

endfunction
