## gd_bezier 
##
## This function is part of Goctave Draw, a set of drawing primitives 
## distributed with Goctave.
##
## This function draws a bezier curve on a bitmap image in color.
## (x0, y0) is the start point, (x3, y3) is the end point, and
## (x1, y1) and (x2, y2) are control points.
## 
## This, unfortunately, is a very time-consuming process. 
## anyone want to rewrite it for me in c++ ?   
##
## For more info, see:
##             Stewart, James.  _Calculus_.  4th ed.  
##                         Brooks/Cole. 1999. p689
## 
##             Durden & Faires. _Numerical Analysis. 6th ed.
##                         Brooks/Cole.  1997. p158-164
##
## Author: Kevin Straight, stra9456@uidaho.edu

function retval = gd_bezier(image, color, x0, y0, x1, y1, x2, y2, x3, y3)

     if (nargin < 10)
        usage ("image = gd_bezier(image, color, x0, y0, x1, y1, x2, x2, x3, y3)");
     endif

     spread = 3*max([norm(x0-x3), norm(x0-x1), norm(x1-x2), norm(x0-x2)]); 

     for i = 0:spread
       t=i/spread;
       x = x0*(1-t)^3 + 3*x1*t*(1-t)^2 + 3*x2*t^2*(1-t) + x3*t^3;
       y = y0*(1-t)^3 + 3*y1*t*(1-t)^2 + 3*y2*t^2*(1-t) + y3*t^3;
       image(round(y),round(x)) = color;
     endfor

     retval = image;

endfunction
