## usage: plot_string = stemleaf (data_set, [stem_unit])
##
## This draws a stem-leaf plot of a vector of data values
##
## stem_unit is the decimal place (eg 1, 10, .001, etc)
## to be used as the "stem"  The default is the one's place
##
## Output is returned as a string, which is more modular than 
## just printing it.
##
## Author: Kevin Straight stra9456@uidaho.edu

function plot_string=stemleaf (data_set, stem_unit)

     if( nargin < 1 )
       usage("plot_string = stemleaf (data_set, [stem_unit])");
     endif

     if( nargin < 2 ) 
       stem_unit=1;
     endif

     data_set=sort(data_set);

     stem = floor(data_set(1)/stem_unit);;

     leaf = data_set(1)-stem*stem_unit;
     leaf = floor((leaf*10)/stem_unit);

     plot_string = strcat(sprintf("\n%d | ", stem),
			  sprintf("%d ", leaf));

     old_stem = stem;

     for i=2:rows(data_set)

       stem = floor(data_set(i)/stem_unit);;

       leaf = data_set(i)-stem*stem_unit;
       leaf = floor((leaf*10)/stem_unit);

       if (old_stem == stem)

	 plot_string = strcat(plot_string, sprintf("%d ", leaf));

       else

	 plot_string = strcat(plot_string, sprintf("\n%d | ", stem),
			      sprintf("%d ", leaf));

       endif

       old_stem = stem;
       
     endfor
  
     plot_string = strcat(plot_string, 
			  sprintf("\n\nn = %g, stem unit = %g\n",
				  rows(data_set),stem_unit));
   
endfunction
